<?php 
if ( ! defined( 'ABSPATH' ) ) die( 'Direct access forbidden.' );

/*
 * Make theme available for translation.
 * Translations can be filed in the /languages/ directory.
 * If you're building a theme based on Livekitchen, use a find and replace
 * to change 'livekitchen' to the name of your theme in all the template files
 */
load_theme_textdomain( 'livekitchen', get_template_directory() . '/languages' );

// Add default posts and comments RSS feed links to head.
add_theme_support( 'automatic-feed-links' );

/*
 * Let WordPress manage the document title.
 * By adding theme support, we declare that this theme does not use a
 * hard-coded <title> tag in the document head, and expect WordPress to
 * provide it for us.
 */
add_theme_support( 'title-tag' );

/*
 * Enable support for Post Thumbnails on posts and pages.
 *
 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
 */
add_theme_support( 'post-thumbnails' );

// This theme uses wp_nav_menu() in one location.
register_nav_menus( array(
    'main-menu' => esc_html__( 'Main Menu', 'livekitchen' ), 
) );

/*
 * Switch default core markup for search form, comment form, and comments
 * to output valid HTML5.
 */
add_theme_support( 'html5', array(
    'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
    ) 
);

/*
 * Enable support for Post Formats.
 * See http://codex.wordpress.org/Post_Formats
 */
add_theme_support( 'post-formats', array(
    'image', 'gallery', 'audio', 'video', 'quote', 'link', 'status', 'chat'
    ) 
);

// Set up the WordPress core custom background feature.
add_theme_support( 'custom-background', apply_filters( 'livekitchen_custom_background_args', array (
    'default-color' => 'fff',
    'default-image' => '',
) ) );

// Add theme support for selective refresh for widgets.
add_theme_support( 'customize-selective-refresh-widgets' );

// Create custom category when theme setup
wp_insert_term(
    esc_html__( 'Featured', 'livekitchen' ),
    'category',
    array(
      'description' => esc_html__( 'Category for featured post', 'livekitchen' ),
      'slug'        => 'featured'
    )
);
wp_insert_term(
    esc_html__( 'Hand Picked', 'livekitchen' ),
    'category',
    array(
      'description' => esc_html__( 'Category for hand picked post', 'livekitchen' ),
      'slug'        => 'hand-picked'
    )
);

/**
 * Enable support for custom header
 * @package Livekitchen
 * @since 1.0
 */
$args = array(
    'flex-width'    => true,
    'width'         => 1920,
    'flex-height'    => true,
    'height'        => 932,
);
add_theme_support( 'custom-header', $args );

/** 
 * Enable WP Responsive embedded content
 *
 * @since 1.0
 */
add_theme_support( 'responsive-embeds' );

/** 
 * Enable WP Gutenberg Block Style
 *
 * @since 1.0
 */
add_theme_support( 'wp-block-styles' );

/**
 * Add Editor Style
 *
 * @since 1.0
 */
// Add support for editor styles.
add_theme_support( 'editor-styles' );

/**
 * Enable support for custom Editor Style.
 *
 * @since 1.0
 */
add_editor_style( 'editor-style.css' );

/**
 * Enable fonts Google font family
 *
 * @since 1.0
 */
function google_fonts_url_editor() {
    $font_url = '';
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== esc_html_x( 'on', 'Google font: on or off', 'livekitchen' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Poppins:300,400,500,600,700|Playfair Display:400,700,900' ), "https://fonts.googleapis.com/css" );
    }
    return $font_url;
}
add_editor_style( google_fonts_url_editor() );
