<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Livekitchen
 */


if ( ! function_exists( 'livekitchen_theme_posts_pagination_nav' ) ) :
/**
 * This is for post pagination
 */
function livekitchen_theme_posts_pagination_nav($wp_query = '', $custom_class = '', $page_url = false) {

    if(!$wp_query) {
        $wp_query = $GLOBALS['wp_query'];
    }

    /** Stop execution if there's only 1 page */
    if( $wp_query->max_num_pages <= 1 )
        return;

    if($page_url == false) {
        $paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
    } else {
        $paged = ( isset($_GET['paged']) ? $_GET['paged'] : 1 );
    }
    
    $max   = intval( $wp_query->max_num_pages );

    /** Add current page to the array */
    if ( $paged >= 1 )
        $links[] = $paged;

    /** Add the pages around the current page to the array */
    if ( $paged >= 3 ) {
        $links[] = $paged - 1;
        $links[] = $paged - 2;
    }

    if ( ( $paged + 2 ) <= $max ) {
        $links[] = $paged + 2;
        $links[] = $paged + 1;
    }
    $div_class = ($custom_class != "") ? $custom_class : "";
    echo '<nav class="paginations"><div class="post-pagination '.$div_class.'  paging-navigation"><ul class="nav-links">' . "\n";

    /** Previous Post Link */
    if ( get_previous_posts_link() ) {
        printf( '<li class="nav-previous">%s</li>' . "\n", get_previous_posts_link('<i class="fa fa-angle-left"></i>' ) );
    } 
    
    /** Link to first page, plus ellipses if necessary */
    if ( ! in_array( 1, $links ) ) {
        $class = 1 == $paged ? ' class="active"' : '';

        printf( '<li%s><a class="page-numbers" href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );

        if ( ! in_array( 2, $links ) )
            echo '<li><span class="page-numbers dots">&hellip;</span></li>';
    }

    /** Link to current page, plus 2 pages in either direction if necessary */
    sort( $links );
    foreach ( (array) $links as $link ) {
        $class = $paged == $link ? ' class="active"' : '';
        printf( '<li%s><a class="page-numbers" href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
    }

    /** Link to last page, plus ellipses if necessary */
    if ( ! in_array( $max, $links ) ) {
        if ( ! in_array( $max - 1, $links ) )
            echo '<li><span class="page-numbers dots">&hellip;</span></li>' . "\n";

        $class = $paged == $max ? ' class="active"' : '';
        printf( '<li%s><a class="page-numbers curent" href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
    }


    /** Next Post Link */
    if ( get_next_posts_link() ) {
        printf( '<li class="nav-next">%s</li>' . "\n", get_next_posts_link( '<i class="fa fa-angle-right"></i>') );
    } 
    echo '</ul></div></nav>' . "\n";
}
endif;

if ( ! function_exists( 'livekitchen_theme_cropping_image_size' ) ) :
/**
 * To show cropping image size
 */
function livekitchen_theme_cropping_image_size() {
    ( isset($_GET["layout"]) ) ? $layout = $_GET["layout"] : $layout = "";
    if ( is_archive() || is_search() ) {
        // archive and search
        if ( livekitchen_theme_template_layout() == "blog-home-one" || livekitchen_theme_template_layout() == "blog-home-two") {
            $image_size = 'livekitchen-theme-list';
        } elseif ( livekitchen_theme_template_layout() == "blog-home-six" ) {
            $image_size = 'livekitchen-theme-blog-six-img';
        }
    } else {
        // home page
        if ( livekitchen_theme_template_layout() == "blog-home-one" || livekitchen_theme_template_layout() == "blog-home-two" || livekitchen_theme_template_layout() == "blog-home-four" || livekitchen_theme_template_layout() == "blog-home-five") {
            $image_size = 'livekitchen-theme-list';
        } elseif ( livekitchen_theme_template_layout() == "blog-home-six" ) {
            $image_size = 'livekitchen-theme-blog-six-img';
        } elseif ( livekitchen_theme_template_layout() == "blog-home-seven" ) {
            $image_size = 'livekitchen-theme-blog-seven-img';
        } elseif ( livekitchen_theme_template_layout() == "blog-home-eight" ) {
            $image_size = 'livekitchen-theme-blog-eight-img';
        }
    }

    return $image_size;
}
endif;

if ( ! function_exists( 'livekitchen_theme_like_comment_view' ) ) :
function livekitchen_theme_like_comment_view() { ?>
    <span class="entry-see"><i class="fa fa-eye"></i>
    <a href="<?php the_permalink(); ?>">
        <?php echo livekitchen_theme_get_post_views(get_the_ID()); ?>
    </a>
    </span>
    <span class="entry-like">
        <?php
        if(is_single()) {
            if( function_exists( 'livekitchen_theme_get_simple_likes_button' ) )  {
                echo livekitchen_theme_get_simple_likes_button( get_the_ID() ); 
            }           
        } else {
            if( function_exists( 'livekitchen_theme_total_like' ) ) {            
                echo '<i class="fa fa-heart-o"></i>';
                livekitchen_theme_total_like();
            }
        }
        ?>
    </span>
    <span class="entry-comment"><i class="fa fa-comments-o"></i>
    <a href="<?php comments_link(); ?>">
        <?php comments_number( esc_html__( '0', 'livekitchen' ), esc_html__( '1', 'livekitchen' ), '%' ); ?>
    </a>
    </span>
    <?php 
}
endif;

if ( ! function_exists( 'livekitchen_theme_tag_list' ) ) :
/**
 * Prints post format icon
 */
function livekitchen_theme_tag_list() {
    if ( has_tag() ) :
        ?>
        <div class="tag clearfix">
            <span class="tags"><?php esc_html_e('Tagged In:', 'livekitchen'); ?></span>
            <?php 
            echo get_the_tag_list("", "", "");
            ?>
        </div> <!-- /.tag -->
        <?php
    endif;
}
endif;

if ( ! function_exists( 'livekitchen_theme_the_category' ) ) :
/**
 * Show category with custom condition
 */
function livekitchen_theme_the_category() {
    $categories = get_the_category(); //get all categories for this post
    foreach( $categories as $category ):
        if ( $category->slug == 'featured' || $category->slug == 'hand-picked') continue;
        echo '<a href="' . get_category_link( $category->term_id ) . '" ' . '>' . $category->name.'</a>';
    endforeach;  
}
endif;

if ( ! function_exists( 'livekitchen_theme_entry_header' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function livekitchen_theme_entry_header() {
    $categories = get_the_category();
    if ( ! empty( $categories ) ) {
    ?>
    <div class="cat-links">
        <?php livekitchen_theme_the_category(); ?>
    </div>
    <?php } 
        the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); 
    ?>
    <div class="entry-meta">
        <div class="meta-content">                                         
            <div class="meta">                                            
                <span class="entry-date"><?php the_time( get_option( 'date_format' ) ); ?></span>
                <span class="devider">/</span>
                <span class="byline">
                    <span class="author vcard">
                        <?php esc_html_e('By: ','livekitchen').the_author_posts_link(); ?>
                    </span>
                </span>
            </div> <!-- /.meta -->
        </div>
    </div> <!-- .entry-meta -->
    <?php
}
endif;

if ( ! function_exists( 'livekitchen_theme_entry_header_single' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function livekitchen_theme_entry_header_single() {
    if ( livekitchen_theme_fw_post_meta('category_name') != "" ) {
        $category_name = (livekitchen_theme_fw_post_meta('category_name') == 'show') ? true : false ;
    } else {
        $category_name = livekitchen_theme_get_customizer_field(array('category_name', true));
    }

    if ($category_name == true) { ?>
        <div class="cat-links">
            <?php livekitchen_theme_the_category(); ?>
        </div>
    <?php }

    the_title( sprintf( '<h2 class="entry-title">', esc_url( get_permalink() ) ), '</h2>' ); 

    if ( livekitchen_theme_fw_post_meta('post_entry_meta') != "" ) {
        $date_author_meta = (livekitchen_theme_fw_post_meta('post_entry_meta') == 'show') ? true : false ;
    } else {
        $date_author_meta = livekitchen_theme_get_customizer_field(array('post_entry_meta', true));
    }

    if ($date_author_meta == true) { ?>
    <div class="entry-meta">
        <div class="meta-content">                                         
            <div class="meta">                                            
                <span class="entry-date"><?php the_time( get_option( 'date_format' ) ); ?></span>
                <span class="devider">/</span>
                <span class="byline">
                    <span class="author vcard">
                        <?php esc_html_e('By: ','livekitchen').the_author_posts_link(); ?>
                    </span>
                </span>
            </div> <!-- /.meta -->
        </div>
    </div> <!-- .entry-meta -->
    <?php
    }
}
endif;

if ( ! function_exists( 'livekitchen_theme_social_share_link' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function livekitchen_theme_social_share_link($before_text = "") { ?>
    <div class="share">   
        <?php if($before_text != ""): ?> 
        <span><?php echo esc_html($before_text); ?></span>    
        <?php endif; ?>               
        <a class="customer share" rel="nofollow" title="<?php esc_attr_e(  'Share on Facebook', 'livekitchen' ); ?>" href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>">
           <i class="fa fa-facebook"></i>
        </a>
        <a class="customer share" rel="nofollow" title="<?php esc_attr_e(  'Share on Twitter', 'livekitchen' ); ?>" href="https://twitter.com/home?status=<?php the_permalink(); ?>" >
            <i class="fa fa-twitter"></i>
        </a>

        <a class="customer share" rel="nofollow" title="<?php esc_attr_e(  'Share on GooglePlus', 'livekitchen' ); ?>" href="https://plus.google.com/share?url=<?php the_permalink(); ?>" >
            <i class="fa fa-google-plus"></i>
        </a>

        <a class="customer share" rel="nofollow" title="<?php esc_attr_e(  'Share on Linkedin', 'livekitchen' ); ?>" href="http://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink(); ?>" >
            <i class="fa fa-linkedin"></i>
        </a>
        <a rel="nofollow" title="<?php esc_attr_e(  'Share on Pinterest', 'livekitchen' ); ?>" href="javascript:void((function()%7Bvar%20e=document.createElement('script');e.setAttribute('type','text/javascript');e.setAttribute('charset','UTF-8');e.setAttribute('src','http://assets.pinterest.com/js/pinmarklet.js?r='+Math.random()*99999999);document.body.appendChild(e)%7D)());">
            <i class="fa fa-pinterest-p"></i>
        </a> 
    </div><!-- /.share-button -->
    <?php
}
endif;

if ( ! function_exists( 'livekitchen_theme_wp_link_pages' ) ) :
/**
 * To show wp_link_pages
 */
function livekitchen_theme_wp_link_pages() {
    wp_link_pages( array(
        'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'livekitchen' ),
        'after'  => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
    ) );
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function livekitchen_theme_categorized_blog() {
    if ( false === ( $all_the_cool_cats = get_transient( 'livekitchen_theme_categories' ) ) ) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories( array(
            'fields'     => 'ids',
            'hide_empty' => 1,

            // We only need to know if there is more than one category.
            'number'     => 2,
        ) );

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count( $all_the_cool_cats );

        set_transient( 'livekitchen_theme_categories', $all_the_cool_cats );
    }

    if ( $all_the_cool_cats > 1 ) {
        // This blog has more than 1 category so livekitchen_theme_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so livekitchen_theme_categorized_blog should return false.
        return false;
    }
}

/**
 * Flush out the transients used in livekitchen_theme_categorized_blog.
 */
function livekitchen_theme_category_transient_flusher() {
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient( 'livekitchen_theme_categories' );
}
add_action( 'edit_category', 'livekitchen_theme_category_transient_flusher' );
add_action( 'save_post',     'livekitchen_theme_category_transient_flusher' );
