<?php 
/* This template for theme function */

if ( ! function_exists( 'livekitchen_theme_preloader' ) ) :
    function livekitchen_theme_preloader() { 
        if (livekitchen_theme_get_customizer_field('preloader_option','preloader')) { ?>
        <div class="preloader">
            <div class="preloader-content">
                <?php echo livekitchen_theme_get_customizer_field('preloader_option','1','preloader_body'); ?>
            </div><!-- /.preloader-content -->
        </div><!-- /.preloader -->
        <?php }
    }
endif;

/*
 * Page Header Title Part
*/
if ( ! function_exists( 'livekitchen_theme_page_header_bg' ) ) :
    function livekitchen_theme_page_header_bg() { ?>
        <?php 
            if( livekitchen_theme_get_customizer_field('page_title_bg_img') != "" ) {
                $background_color = '';
            } else {
                $background_color = 'style=background-color:'. livekitchen_theme_get_customizer_field(array('page_title_bg_color', '#333333')) .'';
            }
        ?>
        <div data-jarallax='{"speed": 0.3, "imgSrc": "<?php echo livekitchen_theme_get_customizer_field('page_title_bg_img', array('url', '')); ?>"}' class="page-heading-area jarallax" <?php echo esc_attr($background_color); ?>>
    <?php }
endif;

/*
 * Main Menu Part
*/
if ( ! function_exists( 'livekitchen_theme_main_menu' ) ) :
    function livekitchen_theme_main_menu() { 
        wp_nav_menu ( array(
            'menu_class' => 'nav navbar-nav mainmenu',
            'container'=> 'ul',
            'theme_location' => 'main-menu',
            'fallback_cb'       => 'Sh_Custom_Walker::fallback_main_menu',
            'walker' => new Sh_Custom_Walker()  
        )); 
    }
endif;

/*
 * Get social_link
*/
if ( ! function_exists( 'livekitchen_theme_social_link' ) ) :
    function livekitchen_theme_social_link($social_link = "", $li_tag = false) { 
        if ( $social_link != "" ) {
            if($li_tag != false ) echo '<li class="social-icon">';
            foreach ( $social_link as $value ) { 
                if ($value['icon']['type'] == "icon-font") { ?>
                    <a target="_blank" href="<?php echo esc_url($value['url']); ?>"><i class="<?php echo esc_attr($value['icon']['icon-class']);?>"></i></a>
                    <?php
                } else { ?>
                    <a target="_blank" href="<?php echo esc_url($value['url']); ?>"><img src="<?php  echo esc_url($value['icon']['url']); ?>" alt="<?php esc_attr_e('img icon','livekitchen' ); ?>" /></a>
                <?php } 
            }
            if($li_tag != false ) echo '</li>';
        } 
    }
endif;

/*
 * To get template layout from options panel
*/
if ( ! function_exists( 'livekitchen_theme_template_layout' ) ) :
    function livekitchen_theme_template_layout() {
        if ( is_archive() || is_search() ) {
            return (defined( 'FW' )) ? livekitchen_theme_get_customizer_field('template_layout_archive','template_layout') : 'blog-home-one';
        } else {            
            return (defined( 'FW' )) ? livekitchen_theme_get_customizer_field('template_layout_options','template_layout') : 'blog-home-one';        
        }
    }
endif;

if ( ! function_exists( 'livekitchen_theme_template_layout_settings' ) ) :
    function livekitchen_theme_template_layout_settings() {
        if ( is_archive() || is_search() ) {
            return (get_theme_mod('fw_options') != "") ? livekitchen_theme_get_customizer_field('template_layout_archive','template_layout') : 'blog-home-one';
        } else {            
            return (get_theme_mod('fw_options') != "") ? livekitchen_theme_get_customizer_field('template_layout_options','template_layout') : 'blog-home-one';        
        }
    }
endif;

if ( ! function_exists( 'livekitchen_theme_get_builder_field' ) ) :
    function livekitchen_theme_get_builder_field($value) {
        if(isset($value)) {
            return $value;
        }
    }
endif;

function livekitchen_theme_excerpt_length($limit) {
    $excerpt = explode(' ', get_the_excerpt(), $limit);
    if (count($excerpt)>=$limit) {
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt).'...';
    } else {
        $excerpt = implode(" ",$excerpt);
    }
    $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
    return $excerpt;
}

function livekitchen_theme_string_to_excerpt($text = "", $limit = null) {
    $excerpt = explode(' ', $text, $limit);
    if (count($excerpt)>=$limit) {
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt).'...';
    } else {
        $excerpt = implode(" ",$excerpt);
    }
    $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
    return $excerpt;
}

/* archive or search page title bar  */
if ( ! function_exists( 'livekitchen_theme_archive_search_page_title' ) ) :
    function livekitchen_theme_archive_search_page_title() {
        if ( is_archive() || is_search() ) { ?>
        <div class="page-header">
            <div class="container">
                <div class="row">
                    <?php
                    if ( is_archive() ) {
                        the_archive_title( '<h2 class="page-title">', '</h2>' );
                    } elseif ( is_search() ) {
                        ?>
                        <h1 class="page-title"><?php printf( '<span>'.esc_html__( 'Search Results for:', 'livekitchen' ).'</span>%s', get_search_query() ); ?></h1>
                        <?php
                    }
                    ?>
                </div>
            </div> 
        </div><!-- /.page-header -->
        <?php
        }
    }
endif;

/**
 ** Functions for converts 0 - 5 to stars
 **/
if( !function_exists('livekitchen_theme_number_to_stars')):
    function livekitchen_theme_number_to_stars($total_stars) {
        $star_integer = intval($total_stars);
        $ratting = '';
        // this echo full stars
        for ($i = 0; $i < $star_integer; $i++) {
            $ratting .= '<i class="fa fa-star"></i>';
        }
        $star_rest = $total_stars - $star_integer;
        // this echo full star or half or empty star
        if ($star_rest >= 0.25 and $star_rest < 0.75) {
            $ratting .= '<i class="fa fa-star-half-o"></i>';
        } else if ($star_rest >= 0.75) {
            $ratting .= '<i class="fa fa-star"></i>';
        } else if ($total_stars != 5) {
            $ratting .= '<i class="fa fa-star-o"></i>';
        }
        // this echo empty star
        for ($i = 0; $i < 4-$star_integer; $i++) {
            $ratting .= '<i class="fa fa-star-o"></i>';
        }
        return $ratting;
    }
endif;