<?php 

/**
 * Sync common Livekitchen_Theme Settings and Customizer options db values
 * @internal
 */
class Livekitchen_Theme_Sync_Customizer_Options {
    public static function init() {
        add_action('customize_save_after', array(__CLASS__, '_livekitchen_after_customizer_save'));
        add_action('fw_settings_form_saved', array(__CLASS__, '_livekitchen_after_settings_save'));
        add_action('fw_settings_form_reset', array(__CLASS__, '_livekitchen_after_settings_save'));
    }

    /**
     * If a customizer option also exists in settings options, copy its value to settings option value
     */
    public static function _livekitchen_after_customizer_save()
    {
        $settings_options = fw_extract_only_options(fw()->theme->get_settings_options());

        foreach (
            array_intersect_key(
                fw_extract_only_options(fw()->theme->get_customizer_options()),
                $settings_options
            )
            as $option_id => $option
        ) {
            if ($option['type'] === $settings_options[$option_id]['type']) {
                fw_set_db_settings_option(
                    $option_id, fw_get_db_customizer_option($option_id)
                );
            }
        }
    }

    /**
     * If a settings option also exists in customizer options, copy its value to customizer option value
     */
    public static function _livekitchen_after_settings_save()
    {
        $customizer_options = fw_extract_only_options(fw()->theme->get_customizer_options());

        foreach (
            array_intersect_key(
                fw_extract_only_options(fw()->theme->get_settings_options()),
                $customizer_options
            )
            as $option_id => $option
        ) {
            if ($option['type'] === $customizer_options[$option_id]['type']) {
                fw_set_db_customizer_option(
                    $option_id, fw_get_db_settings_option($option_id)
                );
            }
        }
    }
}
Livekitchen_Theme_Sync_Customizer_Options::init();

/* livekitchen fw post meta */
if ( ! function_exists( 'livekitchen_theme_fw_post_meta' ) ) :
    function livekitchen_theme_fw_post_meta() {
        $result = get_post_meta( get_the_ID(), 'fw_options', true); 
        foreach (func_get_args() as $arg) {
            if(is_array($arg)) {
                if (!empty($result[$arg[0]])) {
                    $result = $result[$arg[0]];
                } else {  
                  $result = $arg[1];
                }
            } else {
                if (!empty($result[$arg])) {
                    $result = $result[$arg];
                } else { 
                    $result = null;
                }
            }
        }
        return $result;
    }
endif;

/* livekitchen theme return  */
if ( ! function_exists( 'livekitchen_theme_return' ) ) :
    function livekitchen_theme_return($value) {
       return $value;
    }
endif;

if ( ! function_exists( 'livekitchen_theme_get_customizer_field' ) ) :
    function livekitchen_theme_get_customizer_field() {
        $result = get_theme_mod('fw_options');
        foreach (func_get_args() as $arg) {
            if(is_array($arg)) {
                if (!empty($result[$arg[0]])) {
                    $result = $result[$arg[0]];
                } else {  
                  $result = $arg[1];
                }
            } else {
                if (!empty($result[$arg])) {
                    $result = $result[$arg];
                } else { 
                    $result = null;
                }
            }
        }
        return $result;
    }
endif;

/* Typography Field */
/*
 * GOOGLE FONT
 * since 1.0
 */
if(!function_exists('_livekitchen_theme_process_google_fonts')) {
    function _livekitchen_theme_process_google_fonts()
    {
        $include_from_google = array();
        $google_fonts = fw_get_google_fonts();

        $typo_fiels = array(
            fw_get_db_settings_option('global_body_fonts'), 
            fw_get_db_settings_option('blockquote'),   
            fw_get_db_settings_option('hading_one_font'),   
            fw_get_db_settings_option('hading_two_font'),   
            fw_get_db_settings_option('hading_three_font'),   
            fw_get_db_settings_option('hading_four_font'),   
            fw_get_db_settings_option('hading_five_font'),   
            fw_get_db_settings_option('hading_six_font'),   
        );

        foreach ($typo_fiels as $value) {
            if( isset($google_fonts[$value['family']]) ){
                $include_from_google[$value['family']] =   $google_fonts[$value['family']];
            }
        }

        $google_fonts_links = livekitchen_theme_get_remote_fonts($include_from_google);
        // set a option in db for save google fonts link
        update_option( 'livekitchen_theme_google_fonts_link', $google_fonts_links );
    }
    add_action('fw_settings_form_saved', '_livekitchen_theme_process_google_fonts', 999, 2);
    add_action('customize_save_after', '_livekitchen_theme_process_google_fonts', 999, 2);
    add_action('fw_settings_form_reset', '_livekitchen_theme_process_google_fonts', 999, 2);
}

if (!function_exists('livekitchen_theme_get_remote_fonts')) :
    function livekitchen_theme_get_remote_fonts($include_from_google) {
        /**
         * Get remote fonts
         * @param array $include_from_google
         */
        if ( ! sizeof( $include_from_google ) ) {
            return '';
        }

        $html = "//fonts.googleapis.com/css?family=";

        foreach ( $include_from_google as $font => $styles ) {
            $html .= str_replace( ' ', '+', $font ) . ':' . implode( ',', $styles['variants'] ) . '%7C';
        }

        $html = substr( $html, 0, - 1 );

        return $html;
    }
endif;

if (!function_exists('_livekitchen_theme_print_google_fonts_link')) :
    function _livekitchen_theme_print_google_fonts_link() {
        /**
         * Print google fonts link
         */
        wp_enqueue_style('livekitchen-theme-custom-google-font', get_option('livekitchen_theme_google_fonts_link'), false, false, 'all');
    }
    add_action( 'wp_enqueue_scripts', '_livekitchen_theme_print_google_fonts_link' );
endif;
//end goole font

if ( ! function_exists( 'livekitchen_theme_builder_field' ) ) :
    function livekitchen_theme_builder_field($value) {
        if(isset($value)) {
            return $value;
        }
    }
endif;

if ( ! function_exists( 'livekitchen_theme_includes_additional_option_types' ) ) :
    /**
     * Include addition option types
     */
    function livekitchen_theme_includes_additional_option_types() {
        $livekitchen_template_directory = get_template_directory(); 
        load_template( $livekitchen_template_directory . '/inc/custom-option-types/color-palette/class-fw-color-palette-new.php' ); 
    }

    add_action( 'fw_option_types_init', 'livekitchen_theme_includes_additional_option_types' );
endif;