<?php
/**
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @author      WooThemes
 * @package     WooCommerce/Templates
 * @version     1.6.4
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

get_header(); ?>
<?php livekitchen_theme_page_header_bg(); ?>
    <div class="container">
        <div class="row">
            <div class="col-md-12 text-center">
                <h2 class="page-heading"><?php esc_html_e('Food Details', 'livekitchen'); ?></h2><!--/.page-heading-->
            </div><!--/.col-md-12-->
        </div><!--/.row-->
    </div><!--/.container-->
</div><!--/.page-heading-area-->

<!--================= Content Area ===================-->
<div class="shop-single-area bg-white-smoke">
    <div class="container">
        <div class="row">
            <div class="col-md-12">        
                <?php
                    /**
                    * woocommerce_before_single_product hook.
                    *
                    * @hooked wc_print_notices - 10
                    */
                    do_action( 'woocommerce_before_single_product' );

                    if ( post_password_required() ) {
                       echo get_the_password_form();
                       return;
                    }
                ?>
            </div><!-- /.col-md-12 -->
        </div><!-- /.row -->
        <div class="row">
            <?php while ( have_posts() ) : the_post(); ?>
            <div class="col-md-6 shop-single-content"> 
                <div class="shop-single-thumb">
                    <?php 
                    $shop_single    = wc_get_image_size( 'shop_single' );
                    $shop_thumbnail = wc_get_image_size( 'shop_thumbnail' ); 
                    $attachment_ids = $product->get_gallery_image_ids();
                    if(!empty($attachment_ids)) { ?>
                        <div class="shop-thumb-full owl-carousel">
                            <?php foreach( $attachment_ids as $attachment_id ) { ?>
                            <div class="item">
                                <img src="<?php echo esc_url(livekitchen_theme_get_image_crop_size($attachment_id, $shop_single['width'], $shop_single['height'], $shop_single['crop'])); ?>" alt="<?php echo esc_attr(get_the_title()); ?>">
                            </div>
                            <?php } ?>
                        </div>
                        <div class="shop-thumb-list owl-carousel">
                            <?php foreach( $attachment_ids as $attachment_id ) { ?>
                            <div class="item">
                                <img src="<?php echo esc_url(livekitchen_theme_get_image_crop_size($attachment_id, $shop_thumbnail['width'], $shop_thumbnail['height'], $shop_thumbnail['crop'])); ?>" alt="<?php echo esc_attr(get_the_title()); ?>">
                            </div>
                            <?php } ?>
                        </div> 
                    <?php } else {
                        if ( has_post_thumbnail() ) { ?>
                        <figure class="post-thumb">
                            <a href="<?php the_permalink(); ?>"> 
                                <?php livekitchen_theme_post_featured_image($shop_single['width'], $shop_single['height'], $shop_single['crop']); ?>            
                            </a>
                        </figure> <!-- /.post-thumb -->
                        <?php }
                        }
                    ?>  
                </div><!--/.shop-single-thumb--> 
            </div><!--/.col-md-6-->

            <div class="col-md-6 shop-single-sidebar">
                <div class="summary entry-summary"> 
                    <?php
                        /**
                        * woocommerce_single_product_summary hook.
                        *
                        * @hooked woocommerce_template_single_title - 5
                        * @hooked woocommerce_template_single_rating - 10
                        * @hooked woocommerce_template_single_price - 10
                        * @hooked woocommerce_template_single_excerpt - 20
                        * @hooked woocommerce_template_single_add_to_cart - 30
                        * @hooked woocommerce_template_single_meta - 40
                        * @hooked woocommerce_template_single_sharing - 50
                        * @hooked WC_Structured_Data::generate_product_data() - 60
                        */
                        do_action( 'woocommerce_single_product_summary' );
                    ?> 
                </div><!-- .summary --> 
            </div><!--/.col-md-6-->
            <?php endwhile; // end of the loop. ?>
        </div><!--/.row-->
        <div class="row">
            <div class="col-md-12">            
                <?php
                    /**
                    * woocommerce_after_single_product_summary hook.
                    *
                    * @hooked woocommerce_output_product_data_tabs - 10
                    * @hooked woocommerce_upsell_display - 15
                    * @hooked woocommerce_output_related_products - 20
                    */
                    do_action( 'woocommerce_after_single_product_summary' );
                ?>
            </div><!-- /.col-md-12 -->
        </div><!-- /.row --> 
    </div><!--/.container-->
</div><!--/.shop-single-area-->
<?php get_footer();