<?php 

class Livekitchen_Newsletter extends WP_Widget {

	function __construct() {
        $title_n_description = esc_html__('Livekitchen : Mailchimp Newsletter Form', 'livekitchen');
        parent::__construct(
            __CLASS__, //class name
            $title_n_description, // widget title
            array (
                'description' => $title_n_description // widget description
            )
        );
    }

	function widget( $args, $instance ) {
		extract( $args );
		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$description = $instance['description'];
		$action_url = $instance['action_url'];
		$first_last_name = $instance['first_last_name'];
		$button_text = $instance['button_text'];

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ) {
			echo $before_title . $title . $after_title;
		}

		// if this widget active load this script
		if ( is_active_widget( false, false, $this->id_base, true ) ) {
			wp_enqueue_script('livekitchen-theme-mailchimp-newslatter', LIVEKITCHEN_THEME_TEMPLATE_DIR_URL .'/js/ajaxchimp.js', array("jquery"));
		} ?>
		<div class="livekitchen-theme-newsletter-box">
			<div class="newsletter-area">
			    <p class="description text-center"><?php echo esc_html($description); ?></p>
			    <form method="post" name="mc-embedded-subscribe-form" class="validate mc-embedded-subscribe-form">
			        <div class="form-newsletter">
			            <div class="row">
			            	<?php if ( $first_last_name == true ) : ?>
			                <div class="col-md-12">
			                	<input type="text" value="" placeholder="<?php esc_html_e( 'Type Your Name', 'livekitchen' );?>" name="FNAME" class="form-controller" required="required">
							</div><!-- / col-md-6 -->
							<?php endif; ?>

			                <div class="mc-field-group col-md-12">
				                <input type="email" value="" placeholder="<?php esc_html_e( 'Type Your Email', 'livekitchen' );?>" name="EMAIL" class="form-controller email"  required="required">
							</div><!-- / col-md-12 -->

							<div class="col-md-12">
								<div class="text-center">
									<button class="mc-embedded-subscribe" type="submit" name="subscribe"><?php echo esc_html($button_text); ?></button>
								</div><!-- /.text-center -->
								<div class="subscription-success"></div>
								<div class="subscription-error"></div>
							</div>  <!-- / col-md-12 -->
						</div>  <!-- / row -->
					</div>  <!-- / form-newsletter -->
			    </form>  <!-- / signup form -->
			</div> <!-- / newsletter aria -->
			<script type="text/javascript">
			    var $actionUrl = '<?php echo esc_url_raw($action_url) ?>';
			    (function($) {
			        "use strict";
			        $( document ).ready(function() {
			            $('.mc-embedded-subscribe-form').ajaxChimp({
			                callback: mailchimpCallback,
			                url: $actionUrl
			            }); 
			            function mailchimpCallback(resp) {
			                 if (resp.result === 'success') {
			                    $('.subscription-success').html('<i class="fa fa-check"></i>' + resp.msg).fadeIn(1000);
			                    $('.subscription-error').fadeOut(500);
			                    
			                } else if(resp.result === 'error') {
			                    $('.subscription-error').html('<i class="fa fa-times"></i>' + resp.msg).fadeIn(1000);
			                }  
			            }
			        });
			    })(jQuery);
			</script>
		</div><!-- newsletter_box_footer-->
	<?php 
		/* After widget (defined by themes). */
		echo $after_widget;
	}
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$description = $instance['description'];
		$action_url = $instance['action_url'];
		$first_last_name = $instance['first_last_name'];
		$button_text = $instance['button_text'];


		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['description'] = $new_instance['description'];
		$instance['action_url'] = $new_instance['action_url'];
		$instance['first_last_name'] = $new_instance['first_last_name'];
		$instance['button_text'] = $new_instance['button_text'];
		return $instance;
	}
	
	 /** @see WP_Widget::form */
	function form( $instance ) {

			/* Set up some default widget settings. */
			$defaults = array(
				'title' => esc_html__('Newsletter','livekitchen'),
				'action_url' => 'http://softhopper.us11.list-manage.com/subscribe/post?u=559ff170eee6949a359c40740&amp;id=fbbd18e68b',
				'description' => "Join our malling list to receive news and announcements",
				'first_last_name' => true,
				'button_text' => 'Subscribe',
				
	 			);
			$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		
			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e('Title:', 'livekitchen') ?></label>
				<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php if( isset($instance['title']) ) echo esc_attr( $instance['title'] ); ?>" />
			</p>

	    	<p>
				<label for="<?php echo $this->get_field_id( 'action_url' ); ?>"><?php esc_html_e('Form Action URL:', 'livekitchen') ?></label>
				<input type="text" id="<?php echo $this->get_field_id( 'action_url' ); ?>" name="<?php echo $this->get_field_name( 'action_url' ); ?>" value="<?php if( isset($instance['action_url']) ) echo esc_url( $instance['action_url'] ); ?>"  class="widefat" />
			</p>
	        

	    	<p>
				<label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php esc_html_e('Description:', 'livekitchen') ?></label>
				<input type="text" id="<?php echo $this->get_field_id( 'description' ); ?>" name="<?php echo $this->get_field_name( 'description' ); ?>" value="<?php if( isset($instance['description']) ) echo esc_attr($instance['description']); ?>"  class="widefat" />
			</p>


	    	<p>
				<label for="<?php echo $this->get_field_id( 'button_text' ); ?>"><?php esc_html_e('Button Text:', 'livekitchen') ?></label>
				<input type="text" id="<?php echo $this->get_field_id( 'button_text' ); ?>" name="<?php echo $this->get_field_name( 'button_text' ); ?>" value="<?php if( isset($instance['button_text']) ) echo esc_attr($instance['button_text']); ?>"  class="widefat" />
			</p>

			<p>
				<input class="checkbox" type="checkbox" <?php checked( $instance['first_last_name'], true ); ?> id="<?php echo $this->get_field_id( 'first_last_name' ); ?>" name="<?php echo $this->get_field_name( 'first_last_name' ); ?>" value="1"/>
				<label for="<?php echo $this->get_field_id( 'first_last_name' ); ?>"><?php esc_html_e('Show First and Last name', 'livekitchen'); ?></label>
			</p>
	   <?php 
	} // end form function
} //end class